==> haskell-gridtables-0.1.0.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gridtables
version:              0.1.0.0
visibility:           public
id:                   gridtables-0.1.0.0-HNJZC1w0H829f8rLD04YEz
key:                  gridtables-0.1.0.0-HNJZC1w0H829f8rLD04YEz
license:              MIT
copyright:            © 2022 RStudio, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  c240c0c90f4e830b416f8d297c792af2
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.0.2/site-local/gridtables-0.1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gridtables-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.0.0-HNJZC1w0H829f8rLD04YEz
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1
    doclayout-0.4-CzfNS6LlvVd7o1nwIUIYqj parsec-3.1.14.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gridtables-0.1.0.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gridtables
version:              0.1.0.0
visibility:           public
id:                   gridtables-0.1.0.0-59JPWY1bEACDybrTKNvLLl
key:                  gridtables-0.1.0.0-59JPWY1bEACDybrTKNvLLl
license:              MIT
copyright:            © 2022 RStudio, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  91f427571f7b01f0ffec0e8c5cfda242
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.0.2/site-local/gridtables-0.1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/gridtables-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.0.0-59JPWY1bEACDybrTKNvLLl
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1
    doclayout-0.4-JUNdJMPDpmeDSop0PqDUQK parsec-3.1.14.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
